@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,5 +23,4 @@
 #define IOPRIO_CLASS_SHIFT	13
 #define IOPRIO_CLASS_BE		2
 
-extern int ve_ioprio_set(vps_handler *h, envid_t veid,
-				io_param *io_param, vps_param *vps_p);
+extern int ve_ioprio_set(vps_handler *h, envid_t veid, io_param *io_param);
