@@ -21,6 +21,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
+#include <limits.h>
 
 #include "types.h"
 #include "ub.h"
@@ -31,7 +32,7 @@
 #include "vzsyscalls.h"
 
 static inline int setublimit(uid_t uid, unsigned long resource,
-	unsigned long *rlim)
+	const unsigned long *rlim)
 {
 	return syscall(__NR_setublimit, uid, resource, rlim);
 }
@@ -80,6 +81,14 @@ if (ub->name == NULL) {							\
 	ret = VZ_NOTENOUGHUBCPARAMS;					\
 }
 
+	if (is_vswap_config(ub))
+	{
+		CHECK_UB(physpages);
+		CHECK_UB(swappages);
+		return ret;
+	}
+	/* else
+	 * non-vswap case, require all params except swappages */
 	CHECK_UB(kmemsize)
 	CHECK_UB(lockedpages)
 	CHECK_UB(privvmpages)
@@ -157,12 +166,18 @@ const char *get_ub_name(unsigned int res_id)
 
 int set_ublimit(vps_handler *h, envid_t veid, ub_param *ub)
 {
+	int vswap = is_vswap_config(ub);
+	const unsigned long unlim_ub[2] = {LONG_MAX, LONG_MAX};
+	const unsigned long *res;
 
 #define SET_UB_LIMIT(name, id)						\
-if (ub->name != NULL) {							\
-	if (setublimit(veid, id, ub->name)) {				\
+res = ub->name;								\
+if (vswap && !res)							\
+	res = unlim_ub;							\
+if (res != NULL) {							\
+	if (setublimit(veid, id, res)) {				\
 		logger(-1, errno, "setublimit %s %lu:%lu failed",	\
-			get_ub_name(id), ub->name[0], ub->name[1]);	\
+			get_ub_name(id), res[0], res[1]);		\
 		return VZ_SETUBC_ERROR;					\
 	}								\
 }
@@ -222,7 +237,7 @@ int vps_set_ublimit(vps_handler *h, envid_t veid, ub_param *ub)
 	}
 	if ((ret = set_ublimit(h, veid, ub)))
 		return ret;
-	logger(-1, 0, "UB limits were set successfully");
+	logger(0, 0, "UB limits were set successfully");
 	return 0;
 }
 
@@ -396,3 +411,11 @@ int vps_read_ubc(envid_t veid, ub_param *ub)
 	fclose(fd);
 	return !found;
 }
+
+int is_vswap_config(const ub_param *param)
+{
+	return  (param != NULL) &&
+		(param->physpages != NULL) &&
+		(param->physpages[1] != LONG_MAX);
+
+}
