@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include "config.h"
 #include "util.h"
 
-void usage(int rc)
+static void usage(int rc)
 {
 	fprintf(rc ? stderr : stdout, "Usage: vzcalc [-v] <veid>\n");
 	exit(rc);
@@ -52,7 +52,7 @@ if (param->name == NULL) { \
 	return ret;
 }
 
-int calculate(int veid, ub_param *ub, int verbose)
+static int calculate(int veid, ub_param *ub, int verbose)
 {
 	ub_param ub_cur;
 	char tmp[STR_SIZE];
@@ -195,12 +195,13 @@ int main(int argc, char **argv)
 	if (optind == argc)
 		usage(1);
 	if (parse_int(argv[optind], &veid)) {
-		fprintf(stderr, "Invalid VE ID: %s\n", argv[optind]);
+		fprintf(stderr, "Invalid CT ID: %s\n", argv[optind]);
 		exit(1);
 	}
 	get_vps_conf_path(veid, path, sizeof(path));
 	if (stat(path, &st)) {
-		fprintf(stderr, "VE configuration file: %s not found\n", path);
+		fprintf(stderr, "Container configuration file: %s not found\n",
+				path);
 		exit(1);
 	}
 	param = init_vps_param();
